@@ -26,6 +26,7 @@
 #include "gtkshell.h"
 
 void
-     gsh_handle_add_arguments(struct GSH * gsh, int argc, char **argv, int *counter);
+gsh_handle_add_arguments(GSH * gsh, const gint argc, const gchar **argv, 
+	gint *counter);
 
 #endif
