@@ -23,7 +23,7 @@
 #ifndef GSH_BUTTON_H
 #define GSH_BUTTON_H
 
-void
-gsh_command_button(struct GSH * gsh, char *command);
+GtkWidget *
+gsh_add_button(struct GSH * gsh, const gchar * string);
 
 #endif
