@@ -1,6 +1,6 @@
 /*
   AntiRight
-  (c) 2002-2006 Jeffrey Bedard
+  (c) 2002-2007 Jeffrey Bedard
   antiright@gmail.com
 
   This file is part of AntiRight.
@@ -24,7 +24,7 @@
 #define GSH_DIALOG_OPTIONS
 
 void
-gsh_handle_dialog_arguments(struct GSH * gsh, int argc, char **argv,
-			    int *counter);
+gsh_handle_dialog_arguments(GSH * gsh, const gint argc, const gchar **argv,
+			    gint *counter);
 
 #endif
