@@ -21,53 +21,30 @@
 */
 #include "gtkshell.h"
 
+static void
+file_dialog_submit(GtkWidget * dialog)
+{
+	gchar *name;
+
+	name = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog));
+	g_print("%s\n", name);
+	g_free(name);
+}
+
 /* Taken from the GTK+ Reference Manual */
 void
 gsh_file_dialog(struct GSH * gsh, GtkFileChooserAction action)
 {
 	GtkWidget *dialog;
 
-	dialog =
-		gtk_file_chooser_dialog_new(
-					    "File Chooser",
-					    GTK_WINDOW(gsh->window),
-					    action,
-				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-				  GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
-					    NULL);
+	dialog=gtk_file_chooser_dialog_new("File Chooser", 
+		GTK_WINDOW(gsh->widgets.window), action, GTK_STOCK_CANCEL, 
+		GTK_RESPONSE_CANCEL, GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT, NULL);
 
 	if (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_ACCEPT)
-	{
-		gchar *name;
-
-		name = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog));
-		g_print("%s\n", name);
-		g_free(name);
-	}
+		file_dialog_submit(dialog);
 
 	exit(0);
 }
 
-void
-gsh_file_open_dialog(struct GSH * gsh)
-{
-	gsh_file_dialog(gsh, GTK_FILE_CHOOSER_ACTION_OPEN);
-}
 
-void
-gsh_file_save_dialog(struct GSH * gsh)
-{
-	gsh_file_dialog(gsh, GTK_FILE_CHOOSER_ACTION_SAVE);
-}
-
-void
-gsh_folder_create_dialog(struct GSH * gsh)
-{
-	gsh_file_dialog(gsh, GTK_FILE_CHOOSER_ACTION_CREATE_FOLDER);
-}
-
-void
-gsh_folder_open_dialog(struct GSH * gsh)
-{
-	gsh_file_dialog(gsh, GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);
-}
