@@ -27,16 +27,16 @@ void
 gsh_file_dialog(struct GSH * gsh, 
 		GtkFileChooserAction action) __attribute__((noreturn));
 
-void
-gsh_file_open_dialog(struct GSH * gsh) __attribute__((noreturn));
+#define GSH_FILE_OPEN_DIALOG(gsh)\
+	gsh_file_dialog(gsh, GTK_FILE_CHOOSER_ACTION_OPEN)
 
-void
-gsh_file_save_dialog(struct GSH * gsh) __attribute__((noreturn));
+#define GSH_FILE_SAVE_DIALOG(gsh)\
+	gsh_file_dialog(gsh, GTK_FILE_CHOOSER_ACTION_SAVE)
 
-void
-gsh_folder_open_dialog(struct GSH * gsh) __attribute__((noreturn));
+#define GSH_FOLDER_CREATE_DIALOG(gsh)\
+	gsh_file_dialog(gsh, GTK_FILE_CHOOSER_ACTION_CREATE_FOLDER)
 
-void
-gsh_folder_create_dialog(struct GSH * gsh) __attribute__((noreturn));
+#define GSH_FOLDER_OPEN_DIALOG(gsh)\
+	gsh_file_dialog(gsh, GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);
 
 #endif /* !GSH_FILE_DIALOG */
