@@ -22,26 +22,29 @@
 
 #include "gtkshell.h"
 
+static void
+set_font(GtkWidget * widget, const gchar * font)
+{
+	PangoFontDescription *font_desc;
+#define PFD(op, arg) pango_font_description_##op(arg)
+	font_desc = PFD(from_string, font);
+	gtk_widget_modify_font(widget, font_desc);
+	PFD(free, font_desc);
+}
+
 void
 gsh_widget_set_font(GtkWidget *widget, const gchar *font)
 {
+#ifdef DEBUG
 	ARPASSERT(widget);
-	ARPASSERT(font);
-
+#endif /* DEBUG */
+	if(!font) /* Allowed assignmet for uninitialized const var.  */
+		font="Mono 12";
+#ifdef HAVE_VTE
 	if(VTE_IS_TERMINAL(widget))
 		vte_terminal_set_font_from_string(VTE_TERMINAL(widget), font);
-	else
-	{
-		PangoFontDescription *font_desc;
-	
-		font_desc = pango_font_description_from_string(font);
-		gtk_widget_modify_font(widget, font_desc);
-		pango_font_description_free(font_desc);
-	}
+#endif /* HAVE_VTE */
+	else /* Not a terminal.  */
+		set_font(widget, font);
 }
 
-void
-gsh_widget_set_font_mono(GtkWidget *widget)
-{
-	gsh_widget_set_font(widget, "Mono 12");
-}
