@@ -22,37 +22,37 @@
 
 #include "gtkshell.h"
 
+#ifdef LIBGC
+#include <gc.h>
+#endif /* LIBGC */
+
+static void
+setup_gui(struct GSH * gsh, const gint argc, const gchar ** argv)
+{
+	$(gsh, init);
+	$(gsh, parse, argc, argv); /* Setup GUI.  */ 
+	$(gsh, finalize);
+}
+
 int
 main(int argc, char **argv)
 {
-	//Store application structure on stack.
-	struct GSH gsh;
+	struct GSH * gsh;
 
-	gsh.terminal.script=NULL;
-
-	gsh_stack_init(&gsh, &argc, &argv);
-
-#ifdef DEBUG
-	g_debug("rows:\t%d\n", gsh.rows.rows);
-	g_debug("row:\t%d\n", gsh.rows.row);
-#endif				/* DEBUG */
-
-	gsh.bflags |= (((argc > 1) && (strlen(argv[1]) == 3))
-		 && !strncmp(argv[1], "-os", 3)) ? GSH_SCROLL : GSH_NONE;
-
-	gsh_setup_containers(&gsh);
-	gsh_parse_arguments(&gsh, argc, argv);
-	gsh_setup_base_container(&gsh);
-
-	gsh_check_and_set_geometry(&gsh);
-	gtk_widget_show(gsh.window);
-	gtk_main();
-
-	if(gsh.terminal.script != NULL)
-	{
-		unlink(gsh.terminal.script);
-		free(gsh.terminal.script);
-	}
+#ifdef LIBGC
+	GC_INIT();
+#endif /* LIBGC */
+	gtk_init(&argc, &argv);
+	gsh=ARNEW(gsh, GSH);
+	setup_gui(gsh, (const gint)argc, (const gchar **)argv);
+#ifdef LIBGC
+	GC_gcollect();
+#endif /* LIBGC */
+	gtk_main(); /* application main loop  */
+#ifndef LIBGC
+	/* Cleanup when finished.  */
+	$(gsh, delete);
+#endif /* not LIBGC */
 
 	return (EXIT_SUCCESS);
 }
