@@ -24,16 +24,12 @@
 #define GSH_ROW_H
 
 void
-     gsh_manage(struct GSH * gsh, GtkWidget *widget);
+gsh_manage(struct GSH * gsh, GtkWidget *widget);
 
 void
-     gsh_manage_unexpanded(struct GSH * gsh, GtkWidget *widget);
+gsh_check_row(struct GSH * gsh);
 
-
-void
-     gsh_new_row(struct GSH * gsh);
-
-void
-     gsh_check_row(struct GSH * gsh);
+struct GSHRows *
+gsh_new_GSHRows();
 
 #endif				/* GSH_ROW_H */
