@@ -1,6 +1,6 @@
 /*
   AntiRight
-  (c) 2002-2007 Jeffrey Bedard
+  (c) 2007 Jeffrey Bedard
   antiright@gmail.com
 
   This file is part of AntiRight.
@@ -23,7 +23,7 @@
 #ifndef GSH_TERMINAL_H
 #define GSH_TERMINAL_H
 
-void
-gsh_setup_terminal(struct GSH * gsh, const gchar * command);
+struct GSH_Terminal *
+gsh_new_GSH_Terminal();
 
 #endif
