@@ -23,19 +23,28 @@
 #ifndef GSH_TEXT_H
 #define GSH_TEXT_H
 
+GtkTextBuffer *
+gsh_text_area_set_text(GtkWidget * widget, const gchar * text);
+
 GtkWidget *
-gsh_setup_command_entry(struct GSH * gsh, char *command);
+gsh_setup_command_entry(struct GSH * gsh, const gchar *command);
 
 void
-gsh_setup_prompt_command_entry(struct GSH * gsh, char *command);
+gsh_setup_prompt_command_entry(struct GSH * gsh, const gchar *command);
 
 GtkWidget *
 gsh_text_area(struct GSH * gsh);
 
 void
-gsh_text_area_set_text(GtkWidget * widget, const gchar * text);
+gsh_text_editor(struct GSH * gsh, const gchar *filename);
 
 void
-gsh_text_editor(struct GSH * gsh, char *filename);
+gsh_editor_save_as(struct GSH * gsh);
+
+void
+gsh_editor_save(struct GSH * gsh);
+
+void
+gsh_editor_open(struct GSH * gsh);
 
 #endif
