@@ -23,19 +23,17 @@
 #ifndef GSH_UPDATED_H
 #define GSH_UPDATED_H
 
-typedef struct
+struct GSHUpdatedWidget
 {
-	void (*function) (const gchar *, gpointer);
-	gchar *command;
-	GtkWidget *widget;
-}      gsh_updater_data;
+	GtkWidget * widget;
+	gchar * command;
+	void (*function)(const gchar *, gpointer);
+	void (*update)(struct GSHUpdatedWidget *);
+	void (*delete)(struct GSHUpdatedWidget *);
+};
 
-void
-gsh_add_updater(struct GSH * gsh,
-		void (*function) (const gchar *, gpointer),
-		const gchar *command, GtkWidget *widget);
-
-void
-gsh_start_updates(struct GSH * gsh);
+struct GSHUpdatedWidget *
+gsh_new_GSHUpdatedWidget(void (*function)(const gchar *, gpointer), 
+	const gchar * command, GtkWidget * widget);
 
 #endif
