@@ -27,25 +27,27 @@ gsh_update_progress(const gchar *command, gpointer widget)
 {
 	gchar *results;
 
+#ifdef DEBUG
 	ARPASSERT(command);
 	ARPASSERT(widget);
+#endif /* DEBUG */
 
-	results = antiright_pipe_read((char *)command);
-	ARPASSERT(results);
 	gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR((GtkWidget *) widget),
-				      strtod(results, NULL));
-	free(results);
+		strtod(results=antiright_pipe_read((char*)command), NULL));
+	g_free(results);
 }
+
 void
 gsh_add_updated_progress(struct GSH * gsh, const gchar *command)
 {
-	GtkWidget *widget;
+	GtkWidget *progress;
 
+#ifdef DEBUG
 	ARPASSERT(gsh);
 	ARPASSERT(command);
-
-	widget = gtk_progress_bar_new();
-	gsh_manage_unexpanded(gsh, widget);
-	gsh_add_updater(gsh, &gsh_update_progress,
-			command, widget);
+#endif /* DEBUG */
+	progress=gtk_progress_bar_new();
+	$(gsh, manage, progress);
+	$(gsh->update, add, ARNEW(gsh, GSHUpdatedWidget, 
+		&gsh_update_progress, command, progress));
 }
