@@ -34,48 +34,10 @@
 #include "string.h"
 #include "system.h"
 #include "util.h"
+#include "tuple.h"
+#include "arguments.h"
+#include "gui.h"
 
-#define ARBUGPARAM(message) \
-	"%s:%d: %s", __FILE__, __LINE__, message
+#include "macros.h"
 
-#ifdef DEBUG
-#define ARBUG(message) \
-	g_debug(ARBUGPARAM(message))
-#else
-#define ARBUG(message) /* disabled */
-#endif /* DEBUG */
-
-#define ARWARN(message) \
-	g_warning(ARBUGPARAM(message))
-
-#define ARERR(message) \
-	g_error(ARBUGPARAM(message))
-
-#define ARBBOOL(x) (x == TRUE)
-#define ARPBOOL(x) (x != NULL)
-
-#define ARASSERT g_assert
-
-#define ARBASSERT(x) \
-	ARASSERT(ARBBOOL(x))
-
-#define ARPASSERT(x) \
-	ARASSERT(ARPBOOL(x))
-
-#define ARIFB(x) \
-	if(ARBBOOL(x))
-
-#define ARIFNB(x) \
-	if(!ARBBOOL(x))
-
-#define ARIFP(x) \
-	if(ARPBOOL(x))
-
-#define ARIFNP(x) \
-	if(!ARPBOOL(x))
-
-#define ARWIFNP(x) \
-	ARIFNP(x) \
-		ARWARN("NULL data passed, operation not performed"); \
-	else
 #endif				/* LIBAR_LIBRARY_H */
