@@ -20,12 +20,16 @@
 
 #ifndef LIBAR_PIPE_H
 #define LIBAR_PIPE_H
-char *
-antiright_pipe_read(char *command_string);
+
+gchar *
+antiright_pipe_read(const gchar *command_string);
 
 gchar *
 antiright_read_file(FILE *file);
 
+gchar *
+antiright_read_named_file(const gchar * filename);
+
 /* void */
 /* antiright_pipe_write(char *command_string, char* data); */
 /* void */
