@@ -23,12 +23,28 @@
 #ifndef LIBAR_STRING_H
 #define LIBAR_STRING_H
 
-/*@printflike@*/gint
-ar_asprintf(gchar **string, 
-	    const gchar *format,
-	    ...) __attribute__((format(printf,2,3)));
+/* Prototype included here, as not defined in glib headers.  */
+gint
+g_vasprintf(gchar ** string, gchar const * format, va_list args);
 
-char *
-antiright_beautified_label(char *current_argument_string);
+gint
+ar_asprintf(gchar **string, const gchar *format, ...);
 
+gchar *
+antiright_beautified_label(const gchar *string);
+
+/* char*      */
+
+/*
+ * antiright_insert_string(char *text, char *insertion, unsigned int
+ * position);
+ */
+/* char* */
+
+/*
+ * antiright_delete_range(char *text, unsigned int start, unsigned int
+ * end);
+ */
+/* char* */
+/* ar_insert_txt(char* source, char* text, unsigned int position); */
 #endif
